@@ -94,7 +94,7 @@ async fn main() {
 	info!("KYEV SK {}", hex::encode(&privkey));
 	info!("KYEV PK {}", hex::encode(&privkey.public_key()));
 
-	let netapp = NetApp::new(netid, privkey);
+	let netapp = NetApp::new(0u64, netid, privkey);
 
 	let mut bootstrap_peers = vec![];
 	for peer in opt.bootstrap_peers.iter() {
