@@ -34,8 +34,11 @@ pub enum Error {
 	#[error(display = "Connection closed")]
 	ConnectionClosed,
 
-	#[error(display = "Remote error: {}", _0)]
-	Remote(String),
+	#[error(display = "Version mismatch: {}", _0)]
+	VersionMismatch(String),
+
+	#[error(display = "Remote error {}: {}", _0, _1)]
+	Remote(u8, String),
 }
 
 impl Error {
@@ -50,7 +53,8 @@ impl Error {
 			Self::NoHandler => 20,
 			Self::ConnectionClosed => 21,
 			Self::Handshake(_) => 30,
-			Self::Remote(_) => 40,
+			Self::VersionMismatch(_) => 31,
+			Self::Remote(c, _) => *c,
 			Self::Message(_) => 99,
 		}
 	}
