@@ -24,6 +24,14 @@ use crate::proto::*;
 use crate::server::*;
 use crate::util::*;
 
+/// Tag which is exchanged between client and server upon connection establishment
+/// to check that they are running compatible versions of Netapp,
+/// composed of 8 bytes for Netapp version and 8 bytes for client version
+pub(crate) type VersionTag = [u8; 16];
+
+/// Value of the Netapp version used in the version tag
+pub(crate) const NETAPP_VERSION_TAG: u64 = 0x6e65746170700004; // netapp 0x0004
+
 #[derive(Serialize, Deserialize, Debug)]
 pub(crate) struct HelloMessage {
 	pub server_addr: Option<IpAddr>,
@@ -48,6 +56,8 @@ type OnDisconnectHandler = Box<dyn Fn(NodeID, bool) + Send + Sync>;
 pub struct NetApp {
 	listen_params: ArcSwapOption<ListenParams>,
 
+	/// Version tag, 8 bytes for netapp version, 8 bytes for app version
+	pub version_tag: VersionTag,
 	/// Network secret key
 	pub netid: auth::Key,
 	/// Our peer ID
@@ -76,10 +86,15 @@ impl NetApp {
 	/// using `.listen()`
 	///
 	/// Our Peer ID is the public key associated to the secret key given here.
-	pub fn new(netid: auth::Key, privkey: ed25519::SecretKey) -> Arc<Self> {
+	pub fn new(app_version_tag: u64, netid: auth::Key, privkey: ed25519::SecretKey) -> Arc<Self> {
+		let mut version_tag = [0u8; 16];
+		version_tag[0..8].copy_from_slice(&u64::to_be_bytes(NETAPP_VERSION_TAG)[..]);
+		version_tag[8..16].copy_from_slice(&u64::to_be_bytes(app_version_tag)[..]);
+
 		let id = privkey.public_key();
 		let netapp = Arc::new(Self {
 			listen_params: ArcSwapOption::new(None),
+			version_tag,
 			netid,
 			id,
 			privkey,
@@ -292,7 +307,7 @@ impl NetApp {
 			if let Some(c) = conn {
 				debug!(
 					"Closing connection to {} ({})",
-					hex::encode(c.peer_id),
+					hex::encode(&c.peer_id[..8]),
 					c.remote_addr
 				);
 				c.close();
@@ -319,7 +334,11 @@ impl NetApp {
 	// has an actual IP address and port we can call them back on.
 	// We will know this when they send a Hello message, which is handled below.
 	pub(crate) fn connected_as_server(&self, id: NodeID, conn: Arc<ServerConn>) {
-		info!("Accepted connection from {}", hex::encode(id));
+		info!(
+			"Accepted connection from {} at {}",
+			hex::encode(&id[..8]),
+			conn.remote_addr
+		);
 
 		self.server_conns.write().unwrap().insert(id, conn);
 	}
@@ -334,7 +353,7 @@ impl NetApp {
 	// We deregister the connection from server_conns and call the
 	// handler registered by on_disconnected
 	pub(crate) fn disconnected_as_server(&self, id: &NodeID, conn: Arc<ServerConn>) {
-		info!("Connection from {} closed", hex::encode(id));
+		info!("Connection from {} closed", hex::encode(&id[..8]));
 
 		let mut conn_list = self.server_conns.write().unwrap();
 		if let Some(c) = conn_list.get(id) {
@@ -357,7 +376,7 @@ impl NetApp {
 	// they know on which port to call us back. (TODO: don't do this if we are
 	// just a simple client and not a full p2p node)
 	pub(crate) fn connected_as_client(&self, id: NodeID, conn: Arc<ClientConn>) {
-		info!("Connection established to {}", hex::encode(id));
+		info!("Connection established to {}", hex::encode(&id[..8]));
 
 		{
 			let old_c_opt = self.client_conns.write().unwrap().insert(id, conn.clone());
@@ -394,7 +413,7 @@ impl NetApp {
 	// The connection is removed from conn_list, and the on_disconnected handler
 	// is called.
 	pub(crate) fn disconnected_as_client(&self, id: &NodeID, conn: Arc<ClientConn>) {
-		info!("Connection to {} closed", hex::encode(id));
+		info!("Connection to {} closed", hex::encode(&id[..8]));
 		let mut conn_list = self.client_conns.write().unwrap();
 		if let Some(c) = conn_list.get(id) {
 			if Arc::ptr_eq(c, &conn) {
@@ -414,7 +433,7 @@ impl NetApp {
 #[async_trait]
 impl EndpointHandler<HelloMessage> for NetApp {
 	async fn handle(self: &Arc<Self>, msg: &HelloMessage, from: NodeID) {
-		debug!("Hello from {:?}: {:?}", hex::encode(from), msg);
+		debug!("Hello from {:?}: {:?}", hex::encode(&from[..8]), msg);
 		if let Some(h) = self.on_connected_handler.load().as_ref() {
 			if let Some(c) = self.server_conns.read().unwrap().get(&from) {
 				let remote_ip = msg.server_addr.unwrap_or_else(|| c.remote_addr.ip());
